tonalitytools.QualityIndicator
==============================

.. abjad-lineage:: abjad.tools.tonalitytools.QualityIndicator.QualityIndicator.QualityIndicator

.. autoclass:: abjad.tools.tonalitytools.QualityIndicator.QualityIndicator.QualityIndicator
   :noindex:

Read-only Properties
--------------------

.. autoattribute:: abjad.tools.tonalitytools.QualityIndicator.QualityIndicator.QualityIndicator.is_uppercase
   :noindex:

.. autoattribute:: abjad.tools.tonalitytools.QualityIndicator.QualityIndicator.QualityIndicator.quality_string
   :noindex:

.. autoattribute:: abjad.tools.tonalitytools.QualityIndicator.QualityIndicator.QualityIndicator.storage_format
   :noindex:

Special Methods
---------------

.. automethod:: abjad.tools.tonalitytools.QualityIndicator.QualityIndicator.QualityIndicator.__eq__
   :noindex:

.. automethod:: abjad.tools.tonalitytools.QualityIndicator.QualityIndicator.QualityIndicator.__ge__
   :noindex:

.. automethod:: abjad.tools.tonalitytools.QualityIndicator.QualityIndicator.QualityIndicator.__gt__
   :noindex:

.. automethod:: abjad.tools.tonalitytools.QualityIndicator.QualityIndicator.QualityIndicator.__le__
   :noindex:

.. automethod:: abjad.tools.tonalitytools.QualityIndicator.QualityIndicator.QualityIndicator.__lt__
   :noindex:

.. automethod:: abjad.tools.tonalitytools.QualityIndicator.QualityIndicator.QualityIndicator.__ne__
   :noindex:

.. automethod:: abjad.tools.tonalitytools.QualityIndicator.QualityIndicator.QualityIndicator.__repr__
   :noindex:
